@@ -10,13 +10,13 @@
 #define __CVSJOB_STUB__
 
 #include <dcopstub.h>
-#include <qobject.h>
-#include <qstring.h>
-#include <qstringlist.h>
 #include <dcopobject.h>
+#include <qstringlist.h>
+#include <qstring.h>
+#include <qobject.h>
 
 
-class CvsJob_stub : virtual public DCOPStub
+class KDE_EXPORT CvsJob_stub : virtual public DCOPStub
 {
 public:
     CvsJob_stub( const QCString& app, const QCString& id );
